/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Client.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.examples.entitybean;

import javax.naming.Context;
import javax.naming.InitialContext;

/**
 * Simple client of the stateless.
 * @author Florent Benoit
 */
public final class Client {

    /**
     * Utility class.
     */
    private Client() {

    }

    /**
     * Main method.
     * @param args the arguments (not required)
     * @throws Exception if exception is found.
     */
    public static void main(final String[] args) throws Exception {
        // if user don't use jclient/client container
        System.setProperty(Context.INITIAL_CONTEXT_FACTORY, "org.objectweb.carol.jndi.spi.MultiOrbInitialContextFactory");

        Context initialContext = new InitialContext();
        SessionFacadeRemote facadeBean = (SessionFacadeRemote) initialContext.lookup("org.objectweb.easybeans.examples.entitybean.SessionFacade@Remote");

        // Adds some employees
        Employee florent = facadeBean.findEmployee(1);
        if (florent == null) {
            facadeBean.addEmployee(1, "Florent");
        }
        Employee whale = facadeBean.findEmployee(2);
        if (whale == null) {
            facadeBean.addEmployee(2, "Whale");
        }

        // Try to get employee with id 1
        Employee employee = facadeBean.findEmployee(1);
        System.out.println("Employee with id 1 = " + employee.getName());

        // Try to get employee with id 2
        employee = facadeBean.findEmployee(2);
        System.out.println("Employee with id 2 = " + employee.getName());

    }

}
