/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EZBContainer.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.api;

import java.io.File;

import javax.persistence.EntityManagerFactory;
import javax.persistence.spi.PersistenceUnitInfo;

/**
 * This interface represents an EasyBeans EJB Container.
 * @author Florent Benoit
 *
 */
public interface EZBContainer {

    /**
     * Gets a factory with its given name.
     * @param factoryName the factory name.
     * @return the factory found or null.
     */
    Factory getFactory(String factoryName);

    /**
     * Gets the id of this container.
     * @return string id.
     */
    String getId();

    /**
     * Gets the name of this container.
     * @return the name.
     */
    String getName();

    /**
     * Start this container.
     * @throws EZBContainerException if the start fails.
     */
    void start() throws EZBContainerException;

    /**
     * Stop this container.
     */
    void stop();

    /**
     * Gets the classloader of the container. May change at each restart of the container.
     * @return a classloader.
     */
    ClassLoader getClassLoader();

    /**
     * Gets the archive used by this container. It can be a .jar file or a directory.
     * @return the archive.
     */
    File getArchive();

    /**
     * Check if the container is available or not.
     * @return true if the container is available.
     */
    boolean isAvailable();

    /**
     * Gets the persistence info object used by this container.
     * @return persistence info object.
     */
    PersistenceUnitInfo getPersistenceUnitInfo();


    /**
     * Gets the entity manager factory used by this container if any.
     * @return an instance of an entity manager factory
     */
    EntityManagerFactory getEntityManagerFactory();

}
