/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Factory.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.api;

import org.objectweb.easybeans.rpc.api.EJBRequest;
import org.objectweb.easybeans.rpc.api.EJBResponse;
import org.objectweb.easybeans.rpc.api.RPCException;

/**
 * This interface is used by all bean factories of EJB 3 container.
 * @author Florent Benoit
 *
 */
public interface Factory {

    /**
     * A request comes to the bean factory and needs to be handled.<br>
     * A response is done which contains the answer.
     * @param request the EJB request.
     * @throws RPCException if the invocation fails.
     * @return a response that have been processed by the factory.
     */
    EJBResponse rpcInvoke(final EJBRequest request) throws RPCException;

    /**
     * Stops the factory.
     */
    void stop();


    /**
     * Gets the container used by this factory.
     * @return container of this factory
     */
    EZBContainer getContainer();

}
