/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxAnnotationEJBsVisitor.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.annotations.analyzer.classes;

import java.util.ArrayList;
import java.util.List;

import org.objectweb.easybeans.deployment.annotations.analyzer.JavaxAnnotationEJBVisitor;
import org.objectweb.easybeans.deployment.annotations.impl.JAnnotationEJB;
import org.objectweb.easybeans.deployment.annotations.metadata.ClassAnnotationMetadata;

/**
 * This class manages the handling of &#64;{@link javax.annotation.EJBs} annotation.
 * @author Florent Benoit
 */
public class JavaxAnnotationEJBsVisitor extends JavaxAnnotationEJBVisitor<ClassAnnotationMetadata> {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/annotation/EJBs;";

    /**
     * List of jAnnotationEJB object.
     */
    private List<JAnnotationEJB> jAnnotationEJBs = null;

    /**
     * Object is added to the list.
     */
    private boolean isAdded = false;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxAnnotationEJBsVisitor(final ClassAnnotationMetadata annotationMetadata) {
        super(annotationMetadata);
        jAnnotationEJBs = new ArrayList<JAnnotationEJB>();
    }

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.objectweb.asm.Type}.
     */
    @Override
    public void visit(final String name, final Object value) {
        // list not empty, need to create another reference
        // at the first item found
        if (jAnnotationEJBs.size() > 0 && isAdded) {
            setJAnnotationEJB(new JAnnotationEJB());
            isAdded = false;
        }

        // do super code
        super.visit(name, value);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        // add object in the list
        if (!isAdded) {
            jAnnotationEJBs.add(getJAnnotationEJB());
            isAdded = true;
        }

        // update list
        getAnnotationMetadata().setJAnnotationEJBs(jAnnotationEJBs);
    }

    /**
     * @return type of the annotation (its description)
     */
    @Override
    public String getType() {
        return TYPE;
    }

}
