/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EjbJarDeploymentDesc.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.xml;

import java.util.HashMap;
import java.util.Map;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;

/**
 * This class makes the availability of deployment descriptors
 * used in an ejb-jar.
 * @author Florent Benoit
 */
public class EjbJarDeploymentDesc {

    /**
     * Logger.
     */
    private static JLog logger = JLogFactory.getLog(EjbJarDeploymentDesc.class);

    /**
     * List of EJB/Bean deployment descriptors.
     */
    private Map<String, BeanDeploymentDesc> beansDeploymentDesc = null;

    /**
     * Constructor.
     */
    public EjbJarDeploymentDesc() {
        beansDeploymentDesc = new HashMap<String, BeanDeploymentDesc>();
    }

    /**
     * Add deployment descriptor for a given Bean.
     * @param beanDeploymentDesc deployment descriptor of a bean.
     */
    public void addBeanDeploymentDesc(final BeanDeploymentDesc beanDeploymentDesc) {
        String key = beanDeploymentDesc.getEjbName();
        // already exists ?
        if (beansDeploymentDesc.containsKey(key)) {
            String msg = logger.getI18n().getMessage("EjbJarDeploymentDesc.addBeanDeploymentDesc.alreadyPresent", key);
            logger.debug(msg);
            throw new IllegalStateException(msg);
        }
        beansDeploymentDesc.put(key, beanDeploymentDesc);
    }

    /**
     * Get Bean deployment desc for a given bean name.
     * @param ejbName key of the map of DD bean.
     * @return Bean deployment desc of a given name.
     */
    public BeanDeploymentDesc getBeanDeploymentDesc(final String ejbName) {
        return beansDeploymentDesc.get(ejbName);
    }

}
