/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DummyDataSource.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.ds;

import java.io.PrintWriter;
import java.io.Serializable;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;

import javax.sql.DataSource;

/**
 * Defines a dummy datasource implementation based on HSQL in memory server.
 * @author florent
 *
 */
public class DummyDataSource implements DataSource, Serializable {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = 2850630613613046426L;

    /**
     * Constructor.<br>
     * Init the driver.
     */
    public DummyDataSource() {
       try {
            Class.forName("org.hsqldb.jdbcDriver");
        } catch (Exception e) {
           e.printStackTrace();
        }
    }

    /**
     * <p>Attempts to establish a connection with the data source that
     * this <code>DataSource</code> object represents.
     *
     * @return  a connection to the data source
     * @exception SQLException if a database access error occurs
     */
    public Connection getConnection() throws SQLException {
        return DriverManager.getConnection("jdbc:hsqldb:mem:easybeans", "sa", "");
    }

    /**
     * <p>Attempts to establish a connection with the data source that
     * this <code>DataSource</code> object represents.
     *
     * @param username the database user on whose behalf the connection is
     *  being made
     * @param password the user's password
     * @return  a connection to the data source
     * @exception SQLException if a database access error occurs
     */
    public Connection getConnection(final String username, final String password) throws SQLException {
        return this.getConnection();
    }


    /**
     * <p>Retrieves the log writer for this <code>DataSource</code>
     * object.
     * @return the log writer for this data source or null if
     *        logging is disabled
     * @exception SQLException if a database access error occurs
     */
    public PrintWriter getLogWriter() throws SQLException {
        throw new SQLException("Not implemented");
    }

    /**
     * <p>Sets the log writer for this <code>DataSource</code>
     * object to the given <code>java.io.PrintWriter</code> object.
     * @param out the new log writer; to disable logging, set to null
     * @exception SQLException if a database access error occurs
     */
    public void setLogWriter(final PrintWriter out) throws SQLException {
        throw new SQLException("Not implemented");
    }

    /**
     * <p>Sets the maximum time in seconds that this data source will wait
     * while attempting to connect to a database.
     * @param seconds the data source login time limit
     * @exception SQLException if a database access error occurs.
     */
    public void setLoginTimeout(final int seconds) throws SQLException {
        throw new SQLException("Not implemented");
    }

    /**
     * Gets the maximum time in seconds that this data source can wait
     * while attempting to connect to a database.
     * @return the data source login time limit
     * @exception SQLException if a database access error occurs.
     */
    public int getLoginTimeout() throws SQLException {
        throw new SQLException("Not implemented");
    }

}
