/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CommonsModelerHelper.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.jmx;

import org.apache.commons.modeler.Registry;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;

/**
 * @author Florent Benoit
 */
public final class CommonsModelerHelper {

    /**
     * Registry of commons modeler.
     */
    private static Registry registry = null;

    /**
     * Logger.
     */
    private static JLog logger = JLogFactory.getLog(CommonsModelerHelper.class);

    /**
     * Utility class, no public constructor.
     */
    private CommonsModelerHelper() {

    }

    /**
     * Load the registry of managed object descriptions.
     * @throws CommonsModelerException if the MBeans cannot be registered.
     */
    public static synchronized void initRegistry() throws CommonsModelerException {

        if (registry == null) {
            // Load registry
            registry = Registry.getRegistry(null, null);

            ClassLoader classLoader = Thread.currentThread().getContextClassLoader();

            // Load descriptors
            try {
                registry.loadDescriptors("org.objectweb.easybeans.deployer", classLoader);
            } catch (Exception e) {
                throw new CommonsModelerException("Cannot load descriptors of commons modeler", e);
            }

            // if (logger.isDebugEnabled()) {
            String[] managedBeans = registry.findManagedBeans();
            logger.info("List of all MBeans descriptors");
            for (String managedBean : managedBeans) {
                logger.info("Found managedBean {0}.", managedBean);
            }
            logger.info("End of list of all MBeans descriptors");

        }
    }

    /**
     * Gets the registry.
     * @return registry object.
     * @throws CommonsModelerException if registry is not initialized.
     */
    public static Registry getRegistry() throws CommonsModelerException {
        initRegistry();
        return registry;
    }
}
