/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ENCInterceptor.java 9 2006-02-19 18:53:32Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.naming;

import org.objectweb.easybeans.api.EasyBeansInterceptor;
import org.objectweb.easybeans.api.EasyBeansInvocationContext;
import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;

/**
 * This interceptor sets the ENC context before calling method.
 * @author Florent Benoit
 */
public class ENCInterceptor implements EasyBeansInterceptor {

    /**
     * Logger.
     */
    private JLog logger = JLogFactory.getLog(ENCInterceptor.class);


    /**
     * Sets ENC context.
     * @param invocationContext context with useful attributes on the current
     *        invocation.
     * @return result of the next invocation (to chain interceptors).
     * @throws Exception needs for signature of interceptor.
     */
    public Object intercept(final EasyBeansInvocationContext invocationContext) throws Exception {
        logger.debug("ENCInterceptor : Setting ENC environment on method {0}", invocationContext.getMethod().getName());
        try {
            return invocationContext.proceed();
        } finally {
            logger.debug("ENCInterceptor : Unset ENC environment");
        }
    }
}
