/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ServerConfig.java 16 2006-02-21 18:52:14Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.server;

import java.io.File;

/**
 * Defines a configuration class that can be used to start the embedded EJB3 server.
 * @author Florent Benoit
 */
public class ServerConfig {

    /**
     * Path where to lookup beans.
     */
    private File ejb3Directory = null;


    /**
     * Launches the registry.<br>
     * By default, it's true.
     */
    private boolean startRegistry = true;

    /**
     * Launches the Transaction manager.<br>
     * By default, it's true.
     */
    private boolean startTM = true;


    /**
     * Start a dummy DS implementation based on HSQL.
     */
    private boolean dummyDataSourceHSQL = true;


    /**
     * Wait at the end of the start.
     */
    private boolean shouldWait = true;


    /**
     * Use of MBeans.
     */
    private boolean useMBeans = true;

    /**
     * @return the path for loading/looking beans.
     */
    public File getEjb3Directory() {
        return ejb3Directory;
    }

    /**
     * Sets the path forloading/looking beans.
     * @param ejb3Path the path for loading beans.
     */
    public void setEjb3Path(final String ejb3Path) {
        this.ejb3Directory = new File(ejb3Path);
        if (!ejb3Directory.exists()) {
            throw new IllegalArgumentException("Path '" + ejb3Path + "' doesn't exists.");
        }
    }

    /**
     * @return true if the registry need to be started, else false.
     */
    public boolean startRegistry() {
        return startRegistry;
    }

    /**
     * @return true if the transaction manager need to be started, else false.
     */
    public boolean startTM() {
        return startTM;
    }

    /**
     * @return true if the dummy datasource will be bind
     */
    public boolean bindDummyDataSourceHSQL() {
        return dummyDataSourceHSQL;
    }

    /**
     * Sets the flag to start or not the registry.
     * @param startRegistry true/false.
     */
    public void setStartRegistry(final boolean startRegistry) {
        this.startRegistry = startRegistry;
    }


    /**
     * Sets the flag to start or not the TM.
     * @param startTM true/false.
     */
    public void setStartTM(final boolean startTM) {
        this.startTM = startTM;
    }

    /**
     * Sets the flag to bind or not a dummy datasource.
     * @param dummyDataSourceHSQL true/false.
     */
    public void setBindDummyDataSourceHSQL(final boolean dummyDataSourceHSQL) {
        this.dummyDataSourceHSQL = dummyDataSourceHSQL;
    }


    /**
     * @return true if the server should wait when starting embedded server.
     */
    public boolean shouldWait() {
        return shouldWait;
    }

    /**
     * Sets if the server will loop at the end of it's startup.
     * @param shouldWait true/false
     */
    public void setShouldWait(final boolean shouldWait) {
        this.shouldWait = shouldWait;
    }


    /**
     * Use or not the MBeans.
     * @return true if this is the case.
     */
    public boolean isUsingMBeans() {
        return useMBeans;
    }

    /**
     * Sets the value for using MBeans.
     * @param useMBeans the boolean value.
     */
    public void setUseMBeans(final boolean useMBeans) {
        this.useMBeans = useMBeans;
    }
}
