/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EJBHelper.java 24 2006-02-22 14:13:52Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.helper;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;


/**
 * This helper is used to do ejb operations.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public final class EJBHelper {

    /**
     * Helper should have a private constructor.
     *
     */
    private EJBHelper(){
    }

    /**
     * Constant used to identify a remote interface.
     */
    public static final String ITF_REMOTE = "@Remote";
    /**
     * Constant used to identify a local interface.
     */
    public static final String ITF_LOCAL = "@Local";

    /**
     * Gets a remote instance of a bean.
     * @param <E> bean element type
     * @param beanClassName classname of the bean
     * @return bean instance
     * @throws Exception if occurs a problem in the instance invokation
     */
    @SuppressWarnings("unchecked")
    public static <E> E getBeanRemoteInstance(final String beanClassName) throws Exception{
        System.setProperty(Context.INITIAL_CONTEXT_FACTORY,
                "org.objectweb.carol.jndi.spi.MultiOrbInitialContextFactory");
        try {
            Context initialContext = new InitialContext();
            E clBean = (E) initialContext.lookup(beanClassName + ITF_REMOTE);
            return clBean;
        } catch (NamingException e) {
            throw e;
        }
    }

    /**
     * Gets a local instance of a bean.
     * @param <E> bean element type
     * @param beanClassName classname of the bean
     * @return bean instance
     * @throws Exception if occurs a problem in the instance invokation
     */
    @SuppressWarnings("unchecked")
    public static <E> E getBeanLocalInstance(final String beanClassName) throws Exception{
        System.setProperty(Context.INITIAL_CONTEXT_FACTORY,
                "org.objectweb.carol.jndi.spi.MultiOrbInitialContextFactory");
        try {
            Context initialContext = new InitialContext();
            E clBean = (E) initialContext.lookup(beanClassName + ITF_LOCAL);
            return clBean;
        } catch (NamingException e) {
            throw e;
        }
    }
}
