/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ListHelper.java 24 2006-02-22 14:13:52Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.helper;

import java.util.List;

/**
 * This helper is used to do list modifications.
 * interceptor variable.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public final class ListHelper {

    /**
     * Helper should have a private constructor.
     *
     */
    private ListHelper(){
    }

    /**
     * Creates a new list with elements of a list, plus new values.
     * @param <E> list type
     * @param list current list
     * @param values values to add
     * @return new list with new values
     * @throws InstantiationException reflection exception
     * @throws IllegalAccessException reflection exception
     */
    @SuppressWarnings("unchecked")
    public static <E> List<E> addValues(final List<E> list, final E[] values) throws InstantiationException,
            IllegalAccessException {

        if (list == null) {
            return null;
        } else {
            //Creates a new instance using reflection
            List<E> lstNew = (List<E>) list.getClass().newInstance();

            // Add values from current list
            lstNew.addAll(list);

            // Add the new values
            if (values != null){
                for (E eObj : values) {
                    lstNew.add(eObj);
                }
            }
            return lstNew;
        }
    }
}
