/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestBeanInheritance00.java 24 2006-02-22 14:13:52Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.interceptors.business;

import static org.objectweb.easybeans.tests.common.asserts.Assert.assertEquals;
import static org.objectweb.easybeans.tests.common.helper.EJBHelper.getBeanLocalInstance;

import java.util.ArrayList;
import java.util.List;

import org.objectweb.easybeans.tests.common.ejbs.stateless.SLSBInheritance00;
import org.objectweb.easybeans.tests.common.ejbs.stateless.SLSBInheritance01;
import org.objectweb.easybeans.tests.common.inheritance.ItfAddElement;
import org.testng.annotations.Configuration;
import org.testng.annotations.Test;

/**
 * Verifies if the bean inheritance is following the JSR220 spec.
 * @reference JSR220-PROPOSED FINAL
 * @requirement Application Server must be running; the bean
 *              org.objectweb.easybeans.tests.common.ejbs.stateless.SLSB*Inheritance*
 *              must be deployed.
 * @setup gets the reference of SLSBClassInterceptorTest00
 * @author Gisele Pinheiro Souza
 * @author Eduardo Studzinski Estima de Castro
 */
public class TestBeanInheritance00 {

    /**
     * Bean used to implement the test.
     */
    private ItfAddElement mtBean00;

    /**
     * Bean used to implement the test.
     */
    private ItfAddElement mtBean01;

    /**
     * Creates a bean to be used in the tests.
     * @throws Exception if there is a problem with the bean initialization.
     */
    @SuppressWarnings("unchecked")
    @Configuration(beforeTestMethod = true)
    public void startUp() throws Exception {
        mtBean00 = getBeanLocalInstance(SLSBInheritance00.class.getName());
        mtBean01 = getBeanLocalInstance(SLSBInheritance01.class.getName());
    }

    /**
     * Verifies if the bean business method is running correctly. The bean
     * business method is implemented by a extended class that implements an
     * interface. The bean doesn't have any
     * @literal{@Local} or
     * @literal{@Remote}.
     * @input List with no values inside.
     * @output List with only one value, the value inserted by the method.
     */
    @SuppressWarnings("unchecked")
    @Test(groups = {"withInheritance"})
    public void test00() {
        // The arrays used to know what is the interceptor order
        List<Integer> arResult = new ArrayList<Integer>();
        List<Integer> arExpected = new ArrayList<Integer>();

        // insert the value of method
        // there are not interceptors in this class, so only
        // the method will be executed
        arExpected.add(SLSBInheritance00.ELEMENT);

        // gets the result
        arResult = mtBean00.addElement(arResult);

        // compares the two values
        assertEquals(arExpected, arResult, "The business method is not running correctly.");
    }

    /**
     * Verifies if the bean business method is running correctly. The bean
     * business method is implemented by a extended class that implements an
     * interface. The bean has a
     * @literal{@Local} to unique interface implemented.
     * @input List with no values inside.
     * @output List with only one value, the value inserted by the method.
     */
    @SuppressWarnings("unchecked")
    @Test(groups = {"withInheritance"})
    public void test01() {
        // The arrays used to know what is the interceptor order
        List<Integer> arResult = new ArrayList<Integer>();
        List<Integer> arExpected = new ArrayList<Integer>();

        // insert the value of method
        // there are not interceptors in this class, so only
        // the method will be executed
        arExpected.add(SLSBInheritance01.ELEMENT);

        // gets the result
        arResult = mtBean01.addElement(arResult);

        // compares the two values
        assertEquals(arExpected, arResult, "The business method is not running correctly.");
    }

}
